memcpy_device_to_host

Function memcpy_device_to_host 

pub unsafe fn memcpy_device_to_host(
    host: *mut c_void,
    device: *const c_void,
    count: usize,
) -> bool
Copy count bytes from a CUDA device pointer to host. Returns false on failure or if libcudart is unavailable.

Safety

The caller must ensure:

  • host points to at least count bytes of writable memory.
  • device points to at least count bytes of valid CUDA device memory (i.e. obtained from a CudaMap::device_ptr() while the map is live).