stream_destroy

Function stream_destroy 

pub unsafe fn stream_destroy(stream: CudaStream)
Destroy a CUDA stream. No-op if libcudart is unavailable.

Safety

stream must be a live stream returned by stream_create and must not be used after this call.