stream_synchronize

Function stream_synchronize 

pub unsafe fn stream_synchronize(stream: CudaStream) -> bool
Block until all work submitted to stream completes. Returns false on failure or if libcudart is unavailable.

Safety

stream must be a live stream returned by stream_create and not yet destroyed.